package com.konaworks.idea.insertinto;

import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.editor.actionSystem.EditorAction;
import com.intellij.openapi.editor.actionSystem.EditorWriteActionHandler;
import com.intellij.openapi.project.Project;
import com.intellij.psi.JavaTokenType;
import com.intellij.psi.PsiDocumentManager;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiFile;

public class InsertIntoAction extends EditorAction {
  public InsertIntoAction() {
    super(new EditorWriteActionHandler() {

      public boolean isEnabled(Editor editor, DataContext dataContext) {
        PsiElement psiElement = getPsiElement(dataContext, editor);
        //noinspection ConstantConditions
        return psiElement != null
            && psiElement.getNode() != null
            && psiElement.getNode().getElementType() == JavaTokenType.STRING_LITERAL;
      }

      public void executeWriteAction(Editor editor, DataContext dataContext) {
        PsiElement psiElement = getPsiElement(dataContext, editor);
        int startIndex = psiElement.getTextOffset();
        int endIndex = startIndex + psiElement.getTextLength();
        int caretOffset = editor.getCaretModel().getOffset();

        if (caretOffset > startIndex && caretOffset < endIndex) {
          editor.getDocument().insertString(editor.getCaretModel().getOffset(), "\" +  + \"");
          editor.getCaretModel().moveToOffset(editor.getCaretModel().getOffset() + 4);
        }
      }

      private PsiElement getPsiElement(DataContext dataContext, Editor editor) {
        Project project = (Project) dataContext.getData(DataConstants.PROJECT);
        PsiFile psiFile = PsiDocumentManager.getInstance(project).getPsiFile(editor.getDocument());

        return psiFile.findElementAt(editor.getCaretModel().getOffset());
      }
    });
  }
}
