/*
 * Copyright 2006 KonaWorks
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.konaworks.idea.javadocroots;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import javax.swing.Icon;
import java.util.Arrays;

class JavaDocRootsHolder {
  @NotNull
  private final String name;
  @NotNull
  private final String[] roots;
  @Nullable
  private final Icon icon;

  public JavaDocRootsHolder(@NotNull String name, @NotNull String[] urls, @Nullable Icon icon) {
    this.name = name;
    this.roots = urls;
    this.icon = icon;
  }

  public String getName() {
    return name;
  }

  public String[] getRoots() {
    return roots;
  }

  public Icon getIcon() {
    return icon;
  }

  public boolean hasRoots() {
    return roots.length != 0;
  }

  public boolean hasMultipleRoots() {
    return roots.length > 1;
  }

  public boolean hasSingleRoot() {
    return roots.length == 1;
  }

  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;

    final JavaDocRootsHolder that = (JavaDocRootsHolder) o;

    return Arrays.equals(roots, that.roots);
  }

  public int hashCode() {
    return Arrays.hashCode(roots);
  }
}
