/*
 * Copyright 2006 KonaWorks
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.konaworks.idea.javadocroots;

import com.intellij.openapi.module.Module;
import com.intellij.openapi.projectRoots.Sdk;
import com.intellij.openapi.roots.ModuleRootManager;
import com.intellij.openapi.roots.OrderRootType;
import com.intellij.openapi.roots.libraries.Library;
import com.intellij.util.Icons;

class JavaDocRootsHolderFactory {

  private JavaDocRootsHolderFactory() {
  }

  public static JavaDocRootsHolder create(Library library) {
    // module libraries haven't got a name, but allways have at exactly one 'classes' jar or directory item...
    final String name = library.getName() != null
        ? library.getName()
        : library.getFiles(OrderRootType.CLASSES)[0].getName();
    return new JavaDocRootsHolder(name, library.getUrls(OrderRootType.JAVADOC), Icons.LIBRARY_ICON);
  }

  public static JavaDocRootsHolder create(Module module) {
    return new JavaDocRootsHolder(module.getName(), ModuleRootManager.getInstance(module).getJavadocUrls(),
        module.getModuleType().getNodeIcon(false));
  }

  public static JavaDocRootsHolder create(Sdk sdk) {
    return new JavaDocRootsHolder(sdk.getName(), sdk.getRootProvider().getUrls(OrderRootType.JAVADOC),
        sdk.getSdkType().getIcon());
  }

  public static JavaDocRootsHolder createNoItemsAvailableMarker() {
    return new JavaDocRootsHolder(Bundle.message("no.javadoc-roots.available"), new String[0], null) {
      public boolean hasRoots() {
        return false;
      }

      public boolean hasMultipleRoots() {
        return false;
      }

      public boolean hasSingleRoot() {
        return false;
      }
    };
  }
}
