package com.konaworks.idea.inspections;

import com.intellij.codeHighlighting.HighlightDisplayLevel;
import com.intellij.codeInsight.daemon.GroupNames;
import com.intellij.codeInspection.InspectionManager;
import com.intellij.codeInspection.LocalInspectionTool;
import com.intellij.codeInspection.LocalQuickFix;
import com.intellij.codeInspection.ProblemDescriptor;
import com.intellij.codeInspection.ProblemHighlightType;
import com.intellij.lang.Language;
import com.intellij.lang.StdLanguages;
import com.intellij.openapi.fileTypes.StdFileTypes;
import com.intellij.openapi.project.Project;
import com.intellij.psi.PsiFile;
import com.intellij.psi.PsiRecursiveElementVisitor;
import com.intellij.psi.xml.XmlComment;
import com.intellij.util.IncorrectOperationException;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

public class JspCvsHistoryInspection extends LocalInspectionTool {

  @NotNull
  public String getShortName() {
    return "KW_JspCvsHistoryInspection";
  }

  @NotNull
  public HighlightDisplayLevel getDefaultLevel() {
    return HighlightDisplayLevel.WARNING;
  }

  public boolean isEnabledByDefault() {
    return true;
  }

  @NotNull
  public String getGroupDisplayName() {
    return GroupNames.MATURITY_GROUP_NAME;
  }

  @NotNull
  public String getDisplayName() {
    return Bundle.message("inspection.name.KW_JspCvsHistoryInspection");
  }


  public ProblemDescriptor[] checkFile(@NotNull final PsiFile file, @NotNull final InspectionManager manager, boolean flag) {
    final List<ProblemDescriptor> problems = new ArrayList<ProblemDescriptor>();

    if (file.getFileType().equals(StdFileTypes.JSP) || file.getFileType().equals(StdFileTypes.JSPX)) {
      Language language = file.getViewProvider().getBaseLanguage();

      if (language.equals(StdLanguages.JSP) || language.equals(StdLanguages.JSPX)) {
        file.accept(new PsiRecursiveElementVisitor() {

          public void visitXmlComment(XmlComment comment) {
            if (comment.getText().contains("$log") || comment.getText().contains("$Log")) {
              problems.add(manager.createProblemDescriptor(comment, "cvs log", REMOVE_QUICK_FIX, ProblemHighlightType.GENERIC_ERROR_OR_WARNING));
            }
          }
        });
      }
    }
    return problems.toArray(new ProblemDescriptor[problems.size()]);
  }

  private LocalQuickFix REMOVE_QUICK_FIX = new RemoveQuickFix();

  private static class RemoveQuickFix implements LocalQuickFix {
    @NotNull
    public String getName() {
      return Bundle.message("quickfix.remove.cvs.log");
    }

    public void applyFix(@NotNull Project project, ProblemDescriptor descriptor) {
      try {
        descriptor.getPsiElement().delete();
      }
      catch (IncorrectOperationException e) {
        // do nothing
      }
    }

    @NotNull
    public String getFamilyName() {
      return getName();
    }
  }
}
