/*
 * Copyright 2006 KonaWorks
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.konaworks.idea.modulegrouping;

class DistributorFactory {

  private DistributorFactory() {
  }

  public static ModulesToGroupsDistributor create(GroupingType groupingType) {
    switch (groupingType) {
      case BY_TYPE:
        return new GroupByTypeDistributor();
      case BY_NAME_PREFIX_OR_SUFFIX:
        return new GroupByNamePartDistributor(GroupByNamePartDistributor.PartType.PREFIX);
      case BY_PARENT_DIR:
        return new GroupByParentDirDistributor();
      case BY_DEV_KIT:
        return new GroupByDevKitDistributor();
      case BY_LANGUAGE_LEVEL:
        return new GroupByLanguageLevelDistributor();
      case BY_VCS_TYPE:
        return new GroupByVcsTypeDistributor();
      default:
        throw new IllegalArgumentException("groupType not supported.");
    }
  }
}
