/*
 * Copyright 2006 KonaWorks
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.konaworks.idea.modulegrouping;

import com.intellij.openapi.module.Module;
import com.intellij.openapi.projectRoots.ProjectJdk;
import com.intellij.openapi.roots.ModuleRootManager;
import org.jetbrains.annotations.Nullable;

import javax.swing.JPanel;
import javax.swing.JRadioButton;

public class GroupByDevKitDistributor extends AbstractGroupByDistributor {
  private JPanel optionsPanel;
  private JRadioButton byNameRadioButton;
  private JRadioButton byTypeRadioButton;
  private JRadioButton byVersionRadioButton;

  private enum Property {
    NAME,
    SDK_TYPE,
    SDK_VERSION,
  }

  private Property groupByProperty = Property.NAME;

  protected String getGroupName(Module module) {
    // note: when the module refers to the 'project jdk', than that one is returned by the following getJdk call.
    final ProjectJdk jdk = ModuleRootManager.getInstance(module).getJdk();
    if (jdk == null) {
      return null;
    }
    switch (groupByProperty) {
      case NAME:
        return jdk.getName();
      case SDK_TYPE:
        return jdk.getSdkType().getPresentableName();
      case SDK_VERSION:
        if (jdk.getVersionString() != null) {
          return jdk.getVersionString();
        } // else : fall through
      default:
        return null;
    }
  }

  @Nullable
  protected JPanel createOptionsPanel() {
    return optionsPanel;
  }

  protected void applyOptions() {
    if (byNameRadioButton.isSelected()) {
      groupByProperty = Property.NAME;
    } else if (byTypeRadioButton.isSelected()) {
      groupByProperty = Property.SDK_TYPE;
    } else if (byVersionRadioButton.isSelected()) {
      groupByProperty = Property.SDK_VERSION;
    }
  }
}
