/*
 * Copyright 2006 KonaWorks
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.konaworks.idea.modulegrouping;

import com.intellij.openapi.module.Module;
import com.intellij.pom.PomModel;
import com.intellij.pom.java.LanguageLevel;
import com.intellij.pom.java.PomJavaAspect;

public class GroupByLanguageLevelDistributor extends AbstractGroupByDistributor {
  protected String getGroupName(Module module) {
    final LanguageLevel languageLevel = module.getLanguageLevel();
    if (languageLevel != null) {
      return languageLevel.getPresentableText();
    } else { // module doesn't have explicit settings, but uses project language level.
      final PomModel pomModel = module.getProject().getModel();
      if (pomModel == null) {
        return null;
      }
      final PomJavaAspect pomJavaAspect = pomModel.getModelAspect(PomJavaAspect.class);
      if (pomJavaAspect == null) {
        return null;
      }
      final LanguageLevel level = pomJavaAspect.getLanguageLevel();
      if (level != null) {
        return level.getPresentableText();
      } else {
        return null;
      }
    }
  }
}
