/*
 * Copyright 2006 KonaWorks
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.konaworks.idea.modulegrouping;

import com.intellij.openapi.module.Module;
import org.jetbrains.annotations.Nullable;

import javax.swing.JPanel;
import javax.swing.JRadioButton;
import java.io.File;

public class GroupByParentDirDistributor extends AbstractGroupByDistributor {
  private JPanel optionsPanel;
  private JRadioButton use1stLevelParentRadioButton;
  private JRadioButton use2ndLevelParentRadioButton;
  private JRadioButton use3rdLevelParentRadioButton;
  private int n;

  protected String getGroupName(Module module) {
    File parent = new File(module.getModuleFilePath()).getParentFile();
    if (n > 1 && parent != null) {
      parent = parent.getParentFile();
    }
    if (n > 2 && parent != null) {
      parent = parent.getParentFile();
    }
    return parent != null ? parent.getName() : null;
  }

  @Nullable
  protected JPanel createOptionsPanel() {
    return optionsPanel;
  }

  protected void applyOptions() {
    if (use1stLevelParentRadioButton.isSelected()) {
      n = 1;
    } else if (use2ndLevelParentRadioButton.isSelected()) {
      n = 2;
    } else if (use3rdLevelParentRadioButton.isSelected()) {
      n = 3;
    } else {
      n = 1;
    }
  }
}
