/*
 * Copyright 2006 KonaWorks
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.konaworks.idea.modulegrouping;

import com.intellij.openapi.actionSystem.ActionGroup;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.actionSystem.Presentation;
import com.intellij.openapi.module.Module;
import com.intellij.openapi.project.Project;

public class GroupModulesActionGroup extends ActionGroup {

  public GroupModulesActionGroup() {
    setPopup(true);
  }

  public void update(AnActionEvent event) {
    final Project project = (Project) event.getDataContext().getData(DataConstants.PROJECT);
    final Module[] modules = (Module[]) event.getDataContext().getData(DataConstants.MODULE_CONTEXT_ARRAY);
    final Presentation presentation = event.getPresentation();
    presentation.setVisible(project != null && modules != null && modules.length != 0);
    if (ModuleSelectionUtil.isImplicitSelectionForAll(modules)) {
      // Since there is no toplevel group node in the project view, the user is provided the option
      // to group all modules when only 1 module is selected.
      presentation.setText(Bundle.message("group.all.modules"));
    } else {
      presentation.setText(Bundle.message("group.modules"));
    }
  }

  public AnAction[] getChildren(AnActionEvent event) {
    if (event == null) {
      return AnAction.EMPTY_ARRAY;
    }
    return new AnAction[] {
        new GroupModulesAction(GroupingType.BY_TYPE),
        new GroupModulesAction(GroupingType.BY_NAME_PREFIX_OR_SUFFIX),
        new GroupModulesAction(GroupingType.BY_PARENT_DIR),
        new GroupModulesAction(GroupingType.BY_DEV_KIT),
        new GroupModulesAction(GroupingType.BY_LANGUAGE_LEVEL),
        new GroupModulesAction(GroupingType.BY_VCS_TYPE),
    };
  }
}
