/*
 * Copyright 2006 KonaWorks
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.konaworks.idea.modulegrouping;

import com.intellij.openapi.module.Module;
import com.intellij.openapi.module.ModuleManager;
import com.intellij.openapi.project.Project;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

class ModuleSelectionUtil {
  private ModuleSelectionUtil() {
  }

  /**
   * Extend the selection with modules that are selected implicitly/indirectly.
   * Which is the case when only one module is selected.
   * @param contextModules current selection to extend
   * @param project guess what should go inhere..
   * @return optionally extended array of modules.
   */
  @NotNull
  public static Module[] extendWithImplicitSelection(@Nullable Module[] contextModules, Project project) {
    if (isImplicitSelectionForAll(contextModules)) {
      return ModuleManager.getInstance(project).getModules();
    } else {
      // contextModules != null is guaranteed via the method call to isImplicitSelectionForAll
      // noinspection ConstantConditions
      return contextModules;
    }
  }

  public static boolean isImplicitSelectionForAll(Module[] contextModules) {
    return contextModules == null || contextModules.length <= 1;
  }
}
