/*
 * Copyright 2006 KonaWorks
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.konaworks.idea.modulegrouping;

import com.intellij.openapi.module.ModifiableModuleModel;
import com.intellij.openapi.module.Module;
import com.intellij.openapi.project.Project;

public interface ModulesToGroupsDistributor {
  /**
   * Groups the modules using the modifiableModuleModel; but does not commit the changes.
   *
   * @param modules               the modules to (re)group.
   * @param modifiableModuleModel to be used to apply the changes to.
   */
  void distribute(Module[] modules, ModifiableModuleModel modifiableModuleModel);

  /**
   * Hook for subclasses to override to enable options.
   * @param project the current project
   * @return a boolean whether the action is to be proceeded. (true=proceed)
   */
  boolean showOptionsPopup(Project project); // not a too sweet design, but imho good enough for the size of this codebase :)
}
